@@ -13,9 +13,9 @@ except IOError as e:
     exit(1)
 
 options = {}
-if args.duedate: options['duedate'] = args.duedate
-if args.priority: options['priority'] = {'name':args.priority}
-if args.project: options['project'] = {'key':args.project}
+if args.duedate is not None: options['duedate'] = args.duedate
+if args.priority is not None: options['priority'] = {'name':args.priority}
+if args.project is not None: options['project'] = {'key':args.project}
 
 task_ext = TaskExtractor(args.host, args.user, args.password, options, dry_run = args.dry_run)
 
